@@ -25,15 +25,15 @@
 #include <stdio.h>
 
 //QT headers
-#include <ntqstring.h>
-#include <ntqlistview.h>
-#include <ntqdom.h>
-#include <ntqobject.h>
-#include <ntqtimer.h>
-#include <ntqregexp.h>
-#include <ntqdir.h>
-#include <ntqfile.h>
-#include <ntqtextstream.h>
+#include <tqstring.h>
+#include <tqlistview.h>
+#include <tqdom.h>
+#include <tqobject.h>
+#include <tqtimer.h>
+#include <tqregexp.h>
+#include <tqdir.h>
+#include <tqfile.h>
+#include <tqtextstream.h>
 
 //KDE headers
 #include <kurl.h>
@@ -85,7 +85,7 @@ class ShowRecord;
  */
 class ConfigElem : public TQObject {
 
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
 
