@@ -59,7 +59,7 @@ class KshowmailView;
 class ConfigList : public TQObject, public TQPtrList<ConfigElem>
 {
 
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
 
