@@ -36,7 +36,7 @@
  */
 class ConfigAccounts : public TDECModule
 {
-Q_OBJECT
+TQ_OBJECT
 
   public:
 
