@@ -49,7 +49,7 @@
  */
 class ConfigFilter : public TDECModule
 {
-Q_OBJECT
+TQ_OBJECT
 
   public:
 
