@@ -41,7 +41,7 @@
  */
 class ConfigLog : public TDECModule
 {
-Q_OBJECT
+TQ_OBJECT
 
   public:
 
