@@ -52,7 +52,7 @@
 class ConfigSpamcheck : public TDECModule
 {
 
-Q_OBJECT
+TQ_OBJECT
 
 
   public:
