@@ -32,7 +32,7 @@
  */
 class ShowHeaderDialog : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
 
   public:
     /**
